#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_summary_analytics
short_description: Resource module for Network Devices
  Summary Analytics
description:
  - Manage operation create of the resource Network
    Devices Summary Analytics. - > Gets the summary
    analytics data related to network devices based
    on the provided input data. This endpoint helps
    to obtain the consolidated insights into the performance
    and status of the monitored network devices. For
    detailed information about the usage of the API,
    please refer to the Open API specification document
    - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    AssuranceNetworkDevices-2.0.1-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Network Devices Summary Analytics's
      aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Network Devices Summary Analytics's
      filters.
    elements: dict
    suboptions:
      key:
        description: Key.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: str
    type: list
  groupBy:
    description: Group By.
    elements: str
    type: list
  page:
    description: Network Devices Summary Analytics's
      page.
    suboptions:
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      sortBy:
        description: Network Devices Summary Analytics's
          sortBy.
        elements: dict
        suboptions:
          name:
            description: Name.
            type: str
          order:
            description: Order.
            type: str
        type: list
    type: dict
  startTime:
    description: Start Time.
    type: int
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      GetsTheSummaryAnalyticsDataRelatedToNetworkDevices
    description: Complete reference of the GetsTheSummaryAnalyticsDataRelatedToNetworkDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!gets-the-summary-analytics-data-related-to-network-devices
notes:
  - SDK Method used are
    devices.Devices.gets_the_summary_analytics_data_related_to_network_devices,
  - Paths used are
    post /dna/data/api/v1/networkDevices/summaryAnalytics,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_devices_summary_analytics:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
      - function: string
        name: string
    attributes:
      - string
    endTime: 0
    filters:
      - key: string
        operator: string
        value: string
    groupBy:
      - string
    page:
      limit: 0
      offset: 0
      sortBy:
        - name: string
          order: string
    startTime: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "attributes": [
          {}
        ],
        "aggregateAttributes": [
          {}
        ],
        "groups": [
          {
            "id": "string",
            "attributes": [
              {
                "name": "string",
                "value": "string"
              }
            ],
            "aggregateAttributes": [
              {
                "name": "string",
                "function": "string",
                "value": 0
              }
            ]
          }
        ]
      },
      "page": [
        {
          "limit": 0,
          "offset": 0,
          "count": 0,
          "sortBy": [
            {
              "name": "string",
              "order": "string"
            }
          ]
        }
      ]
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: endpoint_analytics_dictionaries_info
short_description: Information module for Endpoint Analytics
  Dictionaries
description:
  - Get all Endpoint Analytics Dictionaries.
  - Fetches the list of attribute dictionaries.
version_added: '6.16.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  includeAttributes:
    description:
      - >
        IncludeAttributes query parameter. Flag to indicate
        whether attribute list for each dictionary should
        be included in response.
    type: bool
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for AI Endpoint
      Analytics GetAIEndpointAnalyticsAttributeDictionaries
    description: Complete reference of the GetAIEndpointAnalyticsAttributeDictionaries
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-ai-endpoint-analytics-attribute-dictionaries
notes:
  - SDK Method used are
    ai_endpoint_analytics.AiEndpointAnalytics.get_ai_endpoint_analytics_attribute_dictionaries,
  - Paths used are
    get /dna/intent/api/v1/endpoint-analytics/dictionaries,
"""

EXAMPLES = r"""
---
- name: Get all Endpoint Analytics Dictionaries
  cisco.dnac.endpoint_analytics_dictionaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    includeAttributes: true
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "name": "string",
        "description": "string",
        "attributes": [
          {
            "name": "string",
            "description": "string"
          }
        ]
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: roles
short_description: Resource module for Roles
description:
  - Manage operations create, update and delete of the
    resource Roles.
  - Add a new role in the system.
  - Delete a role in the system.
  - Update a role in the system.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  description:
    description: Description of role.
    type: str
  resourceTypes:
    description: Roles's resourceTypes.
    elements: dict
    suboptions:
      operations:
        description: List of operations allowed for
          the application. Possible values are "gRead",
          "gCreate", "gUpdate", "gRemove", or some combination
          of these.
        elements: str
        type: list
      type:
        description: Name of the application in the
          System.
        type: str
    type: list
  role:
    description: Name of the role.
    type: str
  roleId:
    description: Id of the role.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for User and
      Roles AddRoleAPI
    description: Complete reference of the AddRoleAPI
      API.
    link: https://developer.cisco.com/docs/dna-center/#!add-role-api
  - name: Cisco DNA Center documentation for User and
      Roles DeleteRoleAPI
    description: Complete reference of the DeleteRoleAPI
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-role-api
  - name: Cisco DNA Center documentation for User and
      Roles UpdateRoleAPI
    description: Complete reference of the UpdateRoleAPI
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-role-api
notes:
  - SDK Method used are
    user_and_roles.UserandRoles.add_role_api,
    user_and_roles.UserandRoles.delete_role_api,
    user_and_roles.UserandRoles.update_role_api,
  - Paths used are
    post /dna/system/api/v1/role,
    delete
    /dna/system/api/v1/role/{roleId},
    put /dna/system/api/v1/role,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.roles:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    description: string
    resourceTypes:
      - operations:
          - string
        type: string
    role: string
- name: Update all
  cisco.dnac.roles:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    description: string
    resourceTypes:
      - operations:
          - string
        type: string
    roleId: string
- name: Delete by id
  cisco.dnac.roles:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    roleId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "roleId": "string",
      "message": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: images_cco_sync
short_description: Resource module for Images Cco Sync
description:
  - Manage operation create of the resource Images Cco
    Sync. - > Initiating the synchronization of the
    software images from Cisco.com. The latest and suggested
    images will be retrieved, along with the corresponding
    product name and PIDs for imported and retrieved
    images from Cisco.com. Once the task is completed,
    the API `/intent/api/v1/images?imported=false` will
    display all the images fetched from Cisco.com.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options: {}
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Software
      Image Management (SWIM) InitiatesSyncOfSoftwareImagesFromCiscoCom
    description: Complete reference of the InitiatesSyncOfSoftwareImagesFromCiscoCom
      API.
    link: https://developer.cisco.com/docs/dna-center/#!initiates-sync-of-software-images-from-cisco-com
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.initiates_sync_of_software_images_from_cisco_com,
  - Paths used are
    post /dna/intent/api/v1/images/ccoSync,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.images_cco_sync:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: organizations_wireless_clients_overview_by_device_info
short_description: Information module for organizations _wireless _clients _overview _by _device
description:
  - Get all organizations _wireless _clients _overview _by _device.
  - List access point client count at the moment in an organization.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
  - cisco.meraki.module_info_pagination
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  organizationId:
    description:
      - OrganizationId path parameter. Organization ID.
    type: str
  networkIds:
    description:
      - >
        NetworkIds query parameter. Optional parameter to filter access points client counts by network ID. This filter uses multiple exact matches.
    elements: str
    type: list
  serials:
    description:
      - >
        Serials query parameter. Optional parameter to filter access points client counts by its serial numbers. This filter uses multiple exact
        matches.
    elements: str
    type: list
  campusGatewayClusterIds:
    description:
      - >
        CampusGatewayClusterIds query parameter. Optional parameter to filter access points client counts by MCG cluster IDs. This filter uses
        multiple exact matches.
    elements: str
    type: list
  perPage:
    description:
      - PerPage query parameter. The number of entries per page returned. Acceptable range is 3 - 1000. Default is 1000.
    type: int
  startingAfter:
    description:
      - >
        StartingAfter query parameter. A token used by the server to indicate the start of the page. Often this is a timestamp or an ID but it
        is not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page
        in the HTTP Link header should define it.
    type: str
  endingBefore:
    description:
      - >
        EndingBefore query parameter. A token used by the server to indicate the end of the page. Often this is a timestamp or an ID but it is
        not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page in
        the HTTP Link header should define it.
    type: str
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for wireless getOrganizationWirelessClientsOverviewByDevice
    description: Complete reference of the getOrganizationWirelessClientsOverviewByDevice API.
    link: https://developer.cisco.com/meraki/api-v1/#!get-organization-wireless-clients-overview-by-device
notes:
  - SDK Method used are
    wireless.Wireless.get_organization_wireless_clients_overview_by_device,
  - Paths used are
    get /organizations/{organizationId}/wireless/clients/overview/byDevice,
"""

EXAMPLES = r"""
- name: Get all organizations _wireless _clients _overview _by _device
  cisco.meraki.organizations_wireless_clients_overview_by_device_info:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    networkIds: []
    serials: []
    campusGatewayClusterIds: []
    perPage: 0
    startingAfter: string
    endingBefore: string
    organizationId: string
    total_pages: -1
    direction: next
  register: result
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: dict
  sample: >
    {
      "items": [
        {
          "counts": {
            "byStatus": {
              "online": 0
            }
          },
          "network": {
            "id": "string"
          },
          "serial": "string"
        }
      ],
      "meta": {
        "counts": {
          "items": {
            "remaining": 0,
            "total": 0
          }
        }
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: discovery_summary_info
short_description: Information module for Discovery
  Summary
description:
  - Get all Discovery Summary. - > Returns the devices
    discovered in the given discovery based on given
    filters. Discovery ID can be obtained using the
    "Get Discoveries by range" API.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Discovery ID.
    type: str
  taskId:
    description:
      - TaskId query parameter.
    type: str
  sortBy:
    description:
      - >
        SortBy query parameter. Sort by field. Available
        values are pingStatus, cliStatus,snmpStatus,
        httpStatus and netconfStatus.
    type: str
  sortOrder:
    description:
      - SortOrder query parameter. Order of sorting
        based on sortBy. Available values are 'asc'
        and 'des'.
    type: str
  ipAddress:
    description:
      - IpAddress query parameter. IP Address of the
        device.
    elements: str
    type: list
  pingStatus:
    description:
      - "PingStatus query parameter. Ping status for
        the IP during the job run. Available values
        are 'SUCCESS', 'FAILURE', 'NOT-PROVIDED' and
        'NOT-VALIDATED'. \n"
    elements: str
    type: list
  snmpStatus:
    description:
      - "SnmpStatus query parameter. SNMP status for
        the IP during the job run. Available values
        are 'SUCCESS', 'FAILURE', 'NOT-PROVIDED' and
        'NOT-VALIDATED'. \n"
    elements: str
    type: list
  cliStatus:
    description:
      - "CliStatus query parameter. CLI status for the
        IP during the job run. Available values are
        'SUCCESS', 'FAILURE', 'NOT-PROVIDED' and 'NOT-VALIDATED'.
        \n"
    elements: str
    type: list
  netconfStatus:
    description:
      - "NetconfStatus query parameter. NETCONF status
        for the IP during the job run. Available values
        are 'SUCCESS', 'FAILURE', 'NOT-PROVIDED' and
        'NOT-VALIDATED'. \n"
    elements: str
    type: list
  httpStatus:
    description:
      - "HttpStatus query parameter. HTTP staus for
        the IP during the job run. Available values
        are 'SUCCESS', 'FAILURE', 'NOT-PROVIDED' and
        'NOT-VALIDATED'. \n"
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Discovery
      GetNetworkDevicesFromDiscovery
    description: Complete reference of the GetNetworkDevicesFromDiscovery
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-network-devices-from-discovery
notes:
  - SDK Method used are
    discovery.Discovery.get_network_devices_from_discovery,
  - Paths used are
    get /dna/intent/api/v1/discovery/{id}/summary,
"""

EXAMPLES = r"""
---
- name: Get all Discovery Summary
  cisco.dnac.discovery_summary_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    taskId: string
    sortBy: string
    sortOrder: string
    ipAddress: []
    pingStatus: []
    snmpStatus: []
    cliStatus: []
    netconfStatus: []
    httpStatus: []
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": 0,
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_advisories_results_advisories_info
short_description: Information module for Security Advisories
  Results Advisories
description:
  - Get all Security Advisories Results Advisories.
  - Get security advisories affecting the network devices.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id query parameter. Id of the advisory.
    type: str
  deviceCount:
    description:
      - DeviceCount query parameter. Return advisories
        with deviceCount greater than this deviceCount.
    type: float
  cvssBaseScore:
    description:
      - CvssBaseScore query parameter. Return advisories
        with cvssBaseScore greater than this cvssBaseScore.
        E.g. 8.5.
    type: str
  securityImpactRating:
    description:
      - >
        SecurityImpactRating query parameter. Return
        advisories with this securityImpactRating. Available
        values CRITICAL, HIGH.
    type: str
  offset:
    description:
      - >
        Offset query parameter. The first record to
        show for this page; the first record is numbered
        1. Default value is 1.
    type: float
  limit:
    description:
      - >
        Limit query parameter. The number of records
        to show for this page. Minimum value is 1. Maximum
        value is 500. Default value is 500.
    type: float
  sortBy:
    description:
      - SortBy query parameter. A property within the
        response to sort by.
    type: str
  order:
    description:
      - >
        Order query parameter. Whether ascending or
        descending order should be used to sort the
        response. Available values asc, desc. Default
        value is asc.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Compliance
      GetSecurityAdvisoriesAffectingTheNetworkDevices
    description: Complete reference of the GetSecurityAdvisoriesAffectingTheNetworkDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-security-advisories-affecting-the-network-devices
notes:
  - SDK Method used are
    compliance.Compliance.get_security_advisories_affecting_the_network_devices,
  - Paths used are
    get /dna/intent/api/v1/securityAdvisories/results/advisories,
"""

EXAMPLES = r"""
---
- name: Get all Security Advisories Results Advisories
  cisco.dnac.security_advisories_results_advisories_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    deviceCount: 0
    cvssBaseScore: string
    securityImpactRating: string
    offset: 0
    limit: 0
    sortBy: string
    order: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "deviceCount": 0,
          "cveIds": [
            "string"
          ],
          "publicationUrl": "string",
          "cvssBaseScore": 0,
          "securityImpactRating": "string",
          "firstFixedVersionsList": [
            {
              "vulnerableVersion": "string",
              "fixedVersions": [
                "string"
              ]
            }
          ]
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: lan_automation_port_channels
short_description: Resource module for Lan Automation
  Port Channels
description:
  - Manage operation create of the resource Lan Automation
    Port Channels. - > This API creates a Port Channel
    between two LAN Automation associated devices using
    the PAgP protocol, with a minimum of 2 and a maximum
    of 8 LAN Automated interfaces in UP status.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  device1ManagementIPAddress:
    description: Either device1ManagementIPAddress or
      device1Uuid is required.
    type: str
  device1Uuid:
    description: Either device1ManagementIPAddress or
      device1Uuid is required.
    type: str
  device2ManagementIPAddress:
    description: Either device2ManagementIPAddress or
      device2Uuid is required.
    type: str
  device2Uuid:
    description: Either device2ManagementIPAddress or
      device2Uuid is required.
    type: str
  portChannelMembers:
    description: Lan Automation Port Channels's portChannelMembers.
    elements: dict
    suboptions:
      device1Interface:
        description: Either device1InterfaceUuid or
          device1InterfaceName is required.
        type: str
      device1InterfaceUuid:
        description: Either device1InterfaceUuid or
          device1InterfaceName is required.
        type: str
      device2Interface:
        description: Either device2InterfaceUuid or
          device2InterfaceName is required.
        type: str
      device2InterfaceUuid:
        description: Either device2InterfaceUuid or
          device2InterfaceName is required.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for LAN Automation
      CreateANewPortChannelBetweenDevices
    description: Complete reference of the CreateANewPortChannelBetweenDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-a-new-port-channel-between-devices
notes:
  - SDK Method used are
    lan_automation.LanAutomation.create_a_new_port_channel_between_devices,
  - Paths used are
    post /dna/intent/api/v1/lanAutomation/portChannels,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.lan_automation_port_channels:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    device1ManagementIPAddress: string
    device1Uuid: string
    device2ManagementIPAddress: string
    device2Uuid: string
    portChannelMembers:
      - device1Interface: string
        device1InterfaceUuid: string
        device2Interface: string
        device2InterfaceUuid: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: aaa_services_info
short_description: Information module for Aaa Services
description:
  - Get all Aaa Services. - > Retrieves the list of
    AAA Services and offers basic filtering and sorting
    capabilities. For detailed information about the
    usage of the API, please refer to the Open API specification
    document - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    AAAServices-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive. If `startTime` is not provided,
        API will default to current time.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records
        to return.
    type: int
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting
        point within all records returned by the API.
        It's one based offset. The starting value is
        1.
    type: int
  sortBy:
    description:
      - SortBy query parameter. Field name on which
        sorting needs to be done.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the
        field ascending or descending.
    type: str
  serverIp:
    description:
      - >
        ServerIp query parameter. IP Address of the
        AAA Server. This parameter supports wildcard
        (`*`) character -based search. Example `10.76.81.*`
        or `*56.78*` or `*50.28` Examples serverIp=10.42.3.31
        (single IP Address is requested) serverIp=10.42.3.31&serverIp=name2&fabricVnName=name3
        (multiple IP Addresses are requested).
    type: str
  deviceId:
    description:
      - >
        DeviceId query parameter. The device UUID. Examples
        `deviceId=6bef213c-19ca-4170-8375-b694e251101c`
        (single deviceId is requested) `deviceId=6bef213c-19ca-4170-8375-b694e251101c&deviceId=32219612-819e-4b5e-a96b-cf22aca13dd9
        (multiple networkDeviceIds with & separator).
    type: str
  deviceName:
    description:
      - >
        DeviceName query parameter. Name of the device.
        This parameter supports wildcard (`*`) character
        -based search. Example `wnbu-sjc*` or `*wnbu-sjc*`
        or `*wnbu-sjc` Examples deviceName=wnbu-sjc24.cisco.com
        (single device name is requested) deviceName=wnbu-sjc24.cisco.com&deviceName=wnbu-sjc22.cisco.com
        (multiple device names are requested).
    type: str
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical
        breakdown of the site tree starting from Global
        site name and ending with the specific site
        name. The Root site is named "Global" (Ex. `Global/AreaName/BuildingName/FloorName`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*/San*, */San,
        /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple
        siteHierarchies requested).
    type: str
  deviceSiteHierarchyId:
    description:
      - >
        DeviceSiteHierarchyId query parameter. The full
        hierarchy breakdown of the site tree in id form
        starting from Global site UUID and ending with
        the specific site UUID. (Ex. `globalUuid/areaUuid/buildingUuid/floorUuid`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*uuid*, *uuid,
        uuid*` Examples `?deviceSiteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid
        `(single siteHierarchyId requested) ` ?deviceSiteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&deviceSiteHierarchyId=globalUuid/areaU
        uid2/buildingUuid2/floorUuid2` (multiple siteHierarchyIds
        requested).
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The UUID of the site.
        (Ex. `flooruuid`) Examples `?siteId=id1` (single
        id requested) `?siteId=id1&siteId=id2&siteId=id3`
        (multiple ids requested).
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      RetrievesTheListOfAAAServicesForGivenParameters
    description: Complete reference of the RetrievesTheListOfAAAServicesForGivenParameters
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-list-of-aaa-services-for-given-parameters
notes:
  - SDK Method used are
    devices.Devices.retrieves_the_list_of_aaa_services_for_given_parameters,
  - Paths used are
    get /dna/data/api/v1/aaaServices,
"""

EXAMPLES = r"""
---
- name: Get all Aaa Services
  cisco.dnac.aaa_services_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    limit: 0
    offset: 0
    sortBy: string
    order: string
    serverIp: string
    deviceId: string
    deviceName: string
    siteHierarchy: string
    deviceSiteHierarchyId: string
    siteId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "serverIp": "string",
          "deviceId": "string",
          "deviceName": "string",
          "deviceFamily": "string",
          "deviceSiteHierarchy": "string",
          "deviceSiteId": "string",
          "deviceSiteHierarchyId": "string",
          "transactions": 0,
          "failedTransactions": 0,
          "successfulTransactions": 0,
          "eapTransactions": 0,
          "eapFailedTransactions": 0,
          "eapSuccessfulTransactions": 0,
          "mabTransactions": 0,
          "mabFailedTransactions": 0,
          "mabSuccessfulTransactions": 0,
          "latency": 0,
          "eapLatency": 0,
          "mabLatency": 0
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "sortBy": [
          {
            "name": "string",
            "order": "string"
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: icap_settings_configuration_models_preview_activity_id_network_devices_network_device_id_config
short_description: Resource module for Icap Settings
  Configuration Models Preview Activity Id Network Devices
  Network Device Id Config
description:
  - Manage operation create of the resource Icap Settings
    Configuration Models Preview Activity Id Network
    Devices Network Device Id Config. - > Generates
    the device's CLIs of the ICAP intent for preview
    and approve prior to deploying the ICAP configuration
    intent to the device. After deploying the configuration
    intent, generating intent CLIs will not be available
    for preview. For detailed information about the
    usage of the API, please refer to the Open API specification
    document - https //github.com/cisco-en-programmability/catalyst-center-api-
    specs/blob/main/Assurance/CE_Cat_Center_Org-ICAP_APIs-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  networkDeviceId:
    description: NetworkDeviceId path parameter. Device
      id from intent/api/v1/network-device.
    type: str
  object:
    description: Object.
    type: str
  previewActivityId:
    description: PreviewActivityId path parameter. Activity
      from the POST /deviceConfigugrationModels task
      response.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Sensors
      GeneratesTheDevicesCLIsOfTheICAPConfigurationIntent
    description: Complete reference of the GeneratesTheDevicesCLIsOfTheICAPConfigurationIntent
      API.
    link: https://developer.cisco.com/docs/dna-center/#!generates-the-devices-cl-is-of-the-icap-configuration-intent
notes:
  - SDK Method used are
    sensors.Sensors.generates_the_devices_clis_of_the_i_cap_configuration_intent,
  - Paths used are
    post /dna/intent/api/v1/icapSettings/configurationModels/{previewActivityId}/networkDevices/{networkDeviceId}/config,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.icap_settings_configuration_models_preview_activity_id_network_devices_network_device_id_config:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    networkDeviceId: string
    object: string
    previewActivityId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: templates_template_id_network_profiles_for_sites_profile_id_delete
short_description: Resource module for Templates Template
  Id Network Profiles For Sites Profile Id Delete
description:
  - Manage operation delete of the resource Templates
    Template Id Network Profiles For Sites Profile Id
    Delete.
  - Detach a network profile from a Day-N CLI template
    by the profile ID and template ID.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  profileId:
    description: ProfileId path parameter. The `id`
      of the network profile, retrievable from `GET
      /intent/api/v1/networkProfilesForSites`.
    type: str
  templateId:
    description: TemplateId path parameter. The `id`
      of the template, retrievable from `GET /intent/api/v1/templates`.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Configuration
      Templates DetachANetworkProfileFromADayNCLITemplate
    description: Complete reference of the DetachANetworkProfileFromADayNCLITemplate
      API.
    link: https://developer.cisco.com/docs/dna-center/#!detach-a-network-profile-from-a-day-ncli-template
notes:
  - SDK Method used are
    configuration_templates.ConfigurationTemplates.detach_a_network_profile_from_a_day_n_cli_template,
  - Paths used are
    delete /dna/intent/api/v1/templates/{templateId}/networkProfilesForSites/{profileId},
"""

EXAMPLES = r"""
---
- name: Delete by id
  cisco.dnac.templates_template_id_network_profiles_for_sites_profile_id_delete:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    profileId: string
    templateId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_applications_trend_analytics
short_description: Resource module for Network Applications
  Trend Analytics
description:
  - Manage operation create of the resource Network
    Applications Trend Analytics. - > Retrieves the
    trend analytics of applications experience data
    for the specified time range. The data will be grouped
    based on the given trend time interval. This API
    facilitates obtaining consolidated insights into
    the performance and status of the network applications
    over the specified start and end time. If startTime
    and endTime are not provided, the API defaults to
    the last 24 hours. `siteId` and `trendInterval`
    are mandatory. `siteId` must be a site UUID of a
    building. For detailed information about the usage
    of the API, please refer to the Open API specification
    document - https //github.com/cisco-en-programmability/catalyst-center-api-
    specs/blob/main/Assurance/CE_Cat_Center_Org-NetworkApplications-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Network Applications Trend Analytics's
      aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Network Applications Trend Analytics's
      filters.
    elements: dict
    suboptions:
      key:
        description: Key.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: int
    type: list
  groupBy:
    description: Group By.
    elements: str
    type: list
  headers:
    description: Additional headers.
    type: dict
  page:
    description: Network Applications Trend Analytics's
      page.
    suboptions:
      cursor:
        description: Cursor.
        type: str
      limit:
        description: Limit.
        type: int
      timeSortOrder:
        description: Time Sort Order.
        type: str
    type: dict
  siteIds:
    description: Site Ids.
    elements: str
    type: list
  startTime:
    description: Start Time.
    type: int
  trendInterval:
    description: Trend Interval.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Applications
      RetrievesTheTrendAnalyticsDataRelatedToNetworkApplications
    description: Complete reference of the RetrievesTheTrendAnalyticsDataRelatedToNetworkApplications
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-trend-analytics-data-related-to-network-applications
notes:
  - SDK Method used are
    applications.Applications.retrieves_the_trend_analytics_data_related_to_network_applications,
  - Paths used are
    post /dna/data/api/v1/networkApplications/trendAnalytics,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_applications_trend_analytics:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
      - function: string
        name: string
    attributes:
      - string
    endTime: 0
    filters:
      - key: string
        operator: string
        value: 0
    groupBy:
      - string
    headers: '{{my_headers | from_json}}'
    page:
      cursor: string
      limit: 0
      timeSortOrder: string
    siteIds:
      - string
    startTime: 0
    trendInterval: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "timestamp": 0,
          "attributes": [
            {
              "name": "string",
              "value": "string"
            }
          ],
          "aggregateAttributes": [
            {
              "name": "string",
              "function": "string",
              "value": "string"
            }
          ],
          "groups": [
            {
              "id": "string",
              "attributes": [
                {
                  "name": "string",
                  "value": "string"
                }
              ],
              "aggregateAttributes": [
                {
                  "name": "string",
                  "function": "string",
                  "value": "string"
                }
              ]
            }
          ]
        }
      ],
      "page": {
        "limit": 0,
        "cursor": "string",
        "count": 0,
        "timeSortOrder": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_settings_ap_authorization_lists_info
short_description: Information module for Wireless Settings
  Ap Authorization Lists
description:
  - Get all Wireless Settings Ap Authorization Lists.
    - > Retrieves the AP Authorization Lists that are
    created in the Catalyst Centre network Design for
    wireless. If an AP Authorization List name is given
    as query parameter, then returns respective AP Authorization
    List details including Local and/or Remote authorization.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  apAuthorizationListName:
    description:
      - >
        ApAuthorizationListName query parameter. Employ
        this query parameter to obtain the details of
        the AP Authorization List corresponding to the
        provided apAuthorizationListName.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page. The first record is numbered
        1.
    type: str
  limit:
    description:
      - >
        Limit query parameter. The number of records
        to show for this page. Default is 500 if not
        specified. Maximum allowed limit is 500.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      GetAPAuthorizationLists
    description: Complete reference of the GetAPAuthorizationLists
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-ap-authorization-lists
notes:
  - SDK Method used are
    wireless.Wireless.get_ap_authorization_lists,
  - Paths used are
    get /dna/intent/api/v1/wirelessSettings/apAuthorizationLists,
"""

EXAMPLES = r"""
---
- name: Get all Wireless Settings Ap Authorization Lists
  cisco.dnac.wireless_settings_ap_authorization_lists_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    apAuthorizationListName: string
    offset: string
    limit: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "apAuthorizationListName": "string",
        "localAuthorization": {
          "apMacEntries": [
            "string"
          ],
          "apSerialNumberEntries": [
            "string"
          ]
        },
        "remoteAuthorization": {
          "aaaServers": [
            "string"
          ],
          "authorizeApWithMac": true,
          "authorizeApWithSerialNumber": true
        }
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: planned_access_points
short_description: Resource module for Planned Access
  Points
description:
  - Manage operations create, update and delete of the
    resource Planned Access Points. - > Allows creation
    of a new planned access point on an existing floor
    map including its planned radio and antenna details.
    Use the Get variant of this API to fetch any existing
    planned access points for the floor. The payload
    to create a planned access point is in the same
    format, albeit a single object instead of a list,
    of that API. - > Allow to delete a planned access
    point from an existing floor map including its planned
    radio and antenna details. Use the Get variant of
    this API to fetch the existing planned access points
    for the floor. The instanceUUID listed in each of
    the planned access point attributes acts as the
    path param input to this API to delete that specific
    instance. - > Allows updating a planned access point
    on an existing floor map including its planned radio
    and antenna details. Use the Get variant of this
    API to fetch the existing planned access points
    for the floor. The payload to update a planned access
    point is in the same format, albeit a single object
    instead of a list, of that API.
version_added: '6.0.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  attributes:
    description: Planned Access Points's attributes.
    suboptions:
      createDate:
        description: Created date of the planned access
          point.
        type: float
      domain:
        description: Service domain to which the planned
          access point belongs.
        type: str
      heirarchyName:
        description: Hierarchy name of the planned access
          point.
        type: str
      id:
        description: Unique id of the planned access
          point.
        type: float
      instanceUuid:
        description: Instance uuid of the planned access
          point.
        type: str
      macAddress:
        description: MAC address of the planned access
          point.
        type: str
      name:
        description: Display name of the planned access
          point.
        type: str
      source:
        description: Source of the data used to create
          the planned access point.
        type: str
      typeString:
        description: Type string representation of the
          planned access point.
        type: str
    type: dict
  floorId:
    description: FloorId path parameter. The instance
      UUID of the floor hierarchy element.
    type: str
  isSensor:
    description: Indicates that PAP is a sensor.
    type: bool
  location:
    description: Planned Access Points's location.
    suboptions:
      altitude:
        description: Altitude of the planned access
          point's location.
        type: float
      lattitude:
        description: Latitude of the planned access
          point's location.
        type: float
      longtitude:
        description: Longitude of the planned access
          point's location.
        type: float
    type: dict
  plannedAccessPointUuid:
    description: PlannedAccessPointUuid path parameter.
      The instance UUID of the planned access point
      to delete.
    type: str
  position:
    description: Planned Access Points's position.
    suboptions:
      x:
        description: X-coordinate of the planned access
          point on the map, 0,0 point being the top-left
          corner.
        type: float
      y:
        description: Y-coordinate of the planned access
          point on the map, 0,0 point being the top-left
          corner.
        type: float
      z:
        description: Z-coordinate, or height, of the
          planned access point on the map.
        type: float
    type: dict
  radioCount:
    description: Number of radios of the planned access
      point.
    type: int
  radios:
    description: Planned Access Points's radios.
    elements: dict
    suboptions:
      antenna:
        description: Planned Access Points's antenna.
        suboptions:
          azimuthAngle:
            description: Azimuth angle of the antenna.
            type: float
          elevationAngle:
            description: Elevation angle of the antenna.
            type: float
          gain:
            description: Gain of the antenna.
            type: float
          mode:
            description: Mode of the antenna associated
              with this radio.
            type: str
          name:
            description: Name of the antenna.
            type: str
          type:
            description: Type of the antenna associated
              with this radio.
            type: str
        type: dict
      attributes:
        description: Planned Access Points's attributes.
        suboptions:
          channel:
            description: Channel in which this radio
              operates.
            type: float
          channelString:
            description: Channel string representation.
            type: str
          id:
            description: Id of the radio.
            type: int
          ifMode:
            description: IF mode of the radio.
            type: str
          ifTypeString:
            description: String representation of native
              band.
            type: str
          ifTypeSubband:
            description: Sub band of the radio.
            type: str
          instanceUuid:
            description: Instance Uuid of the radio.
            type: str
          slotId:
            description: Slot number in which the radio
              resides in the parent access point.
            type: float
          txPowerLevel:
            description: Tx Power at which this radio
              operates (in dBm).
            type: float
        type: dict
      isSensor:
        description: Determines if it is sensor or not.
        type: bool
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      CreatePlannedAccessPointForFloor
    description: Complete reference of the CreatePlannedAccessPointForFloor
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-planned-access-point-for-floor
  - name: Cisco DNA Center documentation for Devices
      DeletePlannedAccessPointForFloor
    description: Complete reference of the DeletePlannedAccessPointForFloor
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-planned-access-point-for-floor
  - name: Cisco DNA Center documentation for Devices
      UpdatePlannedAccessPointForFloor
    description: Complete reference of the UpdatePlannedAccessPointForFloor
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-planned-access-point-for-floor
notes:
  - SDK Method used are
    devices.Devices.create_planned_access_point_for_floor,
    devices.Devices.delete_planned_access_point_for_floor,
    devices.Devices.update_planned_access_point_for_floor,
  - Paths used are
    post /dna/intent/api/v1/floors/{floorId}/planned-access-points,
    delete /dna/intent/api/v1/floors/{floorId}/planned-access-points/{plannedAccessPointUuid},
    put /dna/intent/api/v1/floors/{floorId}/planned-access-points,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.planned_access_points:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    attributes:
      createDate: 0
      domain: string
      heirarchyName: string
      id: 0
      instanceUuid: string
      macAddress: string
      name: string
      source: string
      typeString: string
    floorId: string
    isSensor: true
    location:
      altitude: 0
      lattitude: 0
      longtitude: 0
    position:
      x: 0
      y: 0
      z: 0
    radioCount: 0
    radios:
      - antenna:
          azimuthAngle: 0
          elevationAngle: 0
          gain: 0
          mode: string
          name: string
          type: string
        attributes:
          channel: 0
          channelString: string
          id: 0
          ifMode: string
          ifTypeString: string
          ifTypeSubband: string
          instanceUuid: string
          slotId: 0
          txPowerLevel: 0
        isSensor: true
- name: Create
  cisco.dnac.planned_access_points:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    attributes:
      createDate: 0
      domain: string
      heirarchyName: string
      id: 0
      instanceUuid: string
      macAddress: string
      name: string
      source: string
      typeString: string
    floorId: string
    isSensor: true
    location:
      altitude: 0
      lattitude: 0
      longtitude: 0
    position:
      x: 0
      y: 0
      z: 0
    radioCount: 0
    radios:
      - antenna:
          azimuthAngle: 0
          elevationAngle: 0
          gain: 0
          mode: string
          name: string
          type: string
        attributes:
          channel: 0
          channelString: string
          id: 0
          ifMode: string
          ifTypeString: string
          ifTypeSubband: string
          instanceUuid: string
          slotId: 0
          txPowerLevel: 0
        isSensor: true
- name: Delete by id
  cisco.dnac.planned_access_points:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    floorId: string
    plannedAccessPointUuid: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_images_info
short_description: Information module for Network Device
  Images
description:
  - Get all Network Device Images. - > This API retrieves
    information about running images and golden image
    bundle, if they are available for network devices.
    It also provides network device update status and
    image update status related to the golden image
    bundle and the compatible features supported by
    the network devices.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  managementAddress:
    description:
      - ManagementAddress query parameter. IP address
        or DNS name used to access and manage network
        devices.
    type: str
  networkDeviceImageStatus:
    description:
      - >
        NetworkDeviceImageStatus query parameter. Network
        device image status with respect to golden images.
        Available values OUTDATED, UP_TO_DATE, UNKNOWN,
        CONFLICTED, UNSUPPORTED.
    type: str
  networkDeviceUpdateStatus:
    description:
      - >
        NetworkDeviceUpdateStatus query parameter. Network
        device current update status with respect to
        golden images. Available values DISTRIBUTION_PENDING,
        DISTRIBUTION_IN_PROGRESS, DISTRIBUTION_FAILED,
        ACTIVATION_PENDING, ACTIVATION_IN_PROGRESS,
        ACTIVATION_FAILED, DEVICE_UP_TO_DATE,UNKNOWN.
    type: str
  sortBy:
    description:
      - >
        SortBy query parameter. Sort the response by
        a specified attribute. Available attributes
        for sorting are `id`,`networkDeviceUpdateStatus`,`networkDeviceImageStatus`,
        `goldenImages.name`, `goldenImages.version`,
        `installedImages.name`, `installedImages.version`.
    type: str
  order:
    description:
      - >
        Order query parameter. Whether ascending or
        descending order should be used to sort the
        response. Available values asc, desc.
    type: str
  offset:
    description:
      - >
        Offset query parameter. The first record to
        show for this page; the first record is numbered
        1. The minimum value is 1.
    type: int
  limit:
    description:
      - >
        Limit query parameter. The number of records
        to show for this page. The minimum and maximum
        values are 1 and 500, respectively.
    type: int
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Software
      Image Management (SWIM) GetTheListOfNetworkDevicesWithImageDetails
    description: Complete reference of the GetTheListOfNetworkDevicesWithImageDetails
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-the-list-of-network-devices-with-image-details
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.get_the_list_of_network_devices_with_image_details,
  - Paths used are
    get /dna/intent/api/v1/networkDeviceImages,
"""

EXAMPLES = r"""
---
- name: Get all Network Device Images
  cisco.dnac.network_device_images_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    managementAddress: string
    networkDeviceImageStatus: string
    networkDeviceUpdateStatus: string
    sortBy: string
    order: string
    offset: 0
    limit: 0
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "managementAddress": "string",
          "networkDevice": {
            "id": "string",
            "productNameOrdinal": 0,
            "productName": "string",
            "supervisorProductName": "string",
            "supervisorProductNameOrdinal": 0
          },
          "networkDeviceImageStatus": "string",
          "networkDeviceUpdateStatus": "string",
          "goldenImages": [
            {
              "id": "string",
              "name": "string",
              "version": "string",
              "imageType": "string",
              "goldenTaggingDetails": {
                "deviceRoles": "string",
                "deviceTags": "string",
                "siteId": "string",
                "siteName": "string",
                "isInherited": true
              }
            }
          ],
          "installedImages": [
            {
              "id": "string",
              "name": "string",
              "version": "string",
              "imageType": "string"
            }
          ],
          "compatibleFeatures": [
            {
              "key": "string",
              "value": "string"
            }
          ]
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wired_network_devices_network_device_id_config_features_intended_configuration_models_preview_activity_id_config
short_description: Resource module for Wired Network
  Devices Network Device Id Config Features Intended
  Configuration Models Preview Activity Id Config
description:
  - Manage operation create of the resource Wired Network
    Devices Network Device Id Config Features Intended
    Configuration Models Preview Activity Id Config.
    - > Generates the device config for the configuration
    model. This API is 'Step 2' in the following workflow
    - Step 1- Use 'POST /intent/api/v1/wired/networkDevices/{networkDeviceId}/configFeatures/intended/configurationModels'
    to start the provision of intended features. The
    response has a taskId which is the previewActivityId
    in all subsequent APIs. The task must be successfully
    complete before proceeding to the next step. It
    is not recommended to proceed when there is any
    task failure in this step. The API 'DELETE /intent/api/v1/wired/networkDevices/{netw
    orkDeviceId}/configFeatures/intended/configurationModels/{previewActivityId}'
    can be used at any step to discard/cancel the provision
    of intended features. Step 2- Use 'POST /intent/api/v1/wired/networkDevices/{netw
    orkDeviceId}/configFeatures/intended/configurationModels/{previewActivityId}/networkDevices/{networkDeviceId}/
    config' to generate device CLIs for preview. The
    response has a task ID. The task must be successfully
    complete before using the GET API to view CLIs.
    It is not recommended to proceed when there is any
    task failures in this step. The API 'DELETE /intent/api/v1/wired/networkDevices/{networkDeviceId}/configFeatures/in
    tended/configurationModels/{previewActivityId}'
    can be used at any step to discard/cancel the provision
    of intended features. Step 3- Use 'GET /intent/api/v1/wired/networkDevices/{networkDeviceId}/configFeatures/inten
    ded/configurationModels/{previewActivityId}/networkDevices/{networkDeviceId}/config'
    to view the CLIs that will be applied to the device.
    Step 4- Use 'POST /intent/api/v1/wired/networkDevices/{networkDeviceId}/configF
    eatures/intended/configurationModels/{previewActivityId}/deploy'
    to deploy the intent to the device.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  networkDeviceId:
    description: NetworkDeviceId path parameter. Network
      device ID of the wired device to provision. The
      API /intent/api/v1/network-device can be used
      to get the network device ID.
    type: str
  previewActivityId:
    description: PreviewActivityId path parameter. Activity
      id is taskId from Step 1- POST /intent/api/v1/wired/networkDevices/{networkDeviceId}/configFeatures/intended/configurationModels'.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wired GenerateTheDeviceConfigForTheConfigurationModel
    description: Complete reference of the GenerateTheDeviceConfigForTheConfigurationModel
      API.
    link: https://developer.cisco.com/docs/dna-center/#!generate-the-device-config-for-the-configuration-model
notes:
  - SDK Method used are
    wired.Wired.generate_the_device_config_for_the_configuration_model,
  - Paths used are
    post /dna/intent/api/v1/wired/networkDevices/{networkDeviceId}/configFeatures/intended/configurationModels/{previewActivityId}/config,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.wired_network_devices_network_device_id_config_features_intended_configuration_models_preview_activity_id_config:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    networkDeviceId: string
    previewActivityId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {}
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_threats_rogue_allowed_list
short_description: Resource module for Security Threats
  Rogue Allowed-List
description:
  - Manage operations create and delete of the resource
    Security Threats Rogue Allowed-List.
  - Intent API to add the threat mac address to allowed
    list.
  - Intent API to remove the threat mac address from
    allowed list.
version_added: '6.16.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  macAddress:
    description: MacAddress path parameter. Threat mac
      address which needs to be removed from the allowed
      list. Multiple mac addresses will be removed if
      provided as comma separated values (example 00
      2A 10 51 22 43,00 2A 10 51 22 44). Note In one
      request, maximum 100 mac addresses can be removed.
    type: str
  payload:
    description: Security Threats Rogue Allowed List's
      payload.
    elements: dict
    suboptions:
      category:
        description: Category.
        type: int
      macAddress:
        description: Mac Address.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      AddAllowedMacAddress
    description: Complete reference of the AddAllowedMacAddress
      API.
    link: https://developer.cisco.com/docs/dna-center/#!add-allowed-mac-address
  - name: Cisco DNA Center documentation for Devices
      RemoveAllowedMacAddress
    description: Complete reference of the RemoveAllowedMacAddress
      API.
    link: https://developer.cisco.com/docs/dna-center/#!remove-allowed-mac-address
notes:
  - SDK Method used are
    devices.Devices.add_allowed_mac_address,
    devices.Devices.remove_allowed_mac_address,
  - Paths used are
    post /dna/intent/api/v1/security/threats/rogue/allowed-list,
    delete /dna/intent/api/v1/security/threats/rogue/allowed-list/{macAddress},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.security_threats_rogue_allowed-list:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - category: 0
        macAddress: string
- name: Delete by id
  cisco.dnac.security_threats_rogue_allowed-list:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    macAddress: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": "string",
      "error": {}
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: icap_capture_files_id_info
short_description: Information module for Icap Capture
  Files Id
description:
  - Get Icap Capture Files Id by id. - > Retrieves details
    of a specific ICAP packet capture file. For detailed
    information about the usage of the API, please refer
    to the Open API specification document - https //github.com/cisco-en-programmability/catalyst-
    center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-icap-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. The name of the packet capture
        file, as given by the GET /captureFiles API
        response.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Sensors
      RetrievesDetailsOfASpecificICAPPacketCaptureFile
    description: Complete reference of the RetrievesDetailsOfASpecificICAPPacketCaptureFile
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-details-of-a-specific-icap-packet-capture-file
notes:
  - SDK Method used are
    sensors.Sensors.retrieves_details_of_a_specific_i_cap_packet_capture_file,
  - Paths used are
    get /dna/data/api/v1/icap/captureFiles/{id},
"""

EXAMPLES = r"""
---
- name: Get Icap Capture Files Id by id
  cisco.dnac.icap_capture_files_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "fileName": "string",
        "fileSize": 0,
        "type": "string",
        "clientMac": "string",
        "apMac": "string",
        "fileCreationTimestamp": 0,
        "lastUpdatedTimestamp": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wired_network_devices_id_config_features_deployed_layer2_feature_count_info
short_description: Information module for Wired Network
  Devices Id Config Features Deployed Layer2 Feature
  Count
description:
  - Get Wired Network Devices Id Config Features Deployed
    Layer2 Feature Count by id.
  - The API returns the number of configurations for
    a deployed layer 2 feature on a wired device.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Network device ID of the
        wired device to retrieve configuration for.
    type: str
  feature:
    description:
      - >
        Feature path parameter. Name of the feature
        to retrieve configuration for. The API /dna/intent/api/v1/networkDevices/{id}/configFeatures/supported/layer2
        can be used to get the list of features supported
        on a device.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wired GetNumberOfConfigurationsForADeployedLayer2FeatureOnAWiredDevice
    description: Complete reference of the GetNumberOfConfigurationsForADeployedLayer2FeatureOnAWiredDevice
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-number-of-configurations-for-a-deployed-layer-2-feature-on-a-wired-device
notes:
  - SDK Method used are
    wired.Wired.get_number_of_configurations_for_a_deployed_layer2_feature_on_a_wired_device,
  - Paths used are
    get /dna/intent/api/v1/wired/networkDevices/{id}/configFeatures/deployed/layer2/{feature}/count,
"""

EXAMPLES = r"""
---
- name: Get Wired Network Devices Id Config Features
    Deployed Layer2 Feature Count by id
  cisco.dnac.wired_network_devices_id_config_features_deployed_layer2_feature_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    feature: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": 0,
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: authentication_policy_servers_info
short_description: Information module for Authentication
  Policy Servers
description:
  - Get all Authentication Policy Servers.
  - API to get Authentication and Policy Servers.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  isIseEnabled:
    description:
      - IsIseEnabled query parameter. Valid values are
        true, false.
    type: bool
  state_:
    description:
      - State query parameter. Valid values are ACTIVE,
        DELETED, FAILED, INACTIVE, INPROGRESS, RBAC-FAILURE,
        RBAC-SUCCESS.
    type: str
  role:
    description:
      - Role query parameter. Authentication and Policy
        Server Role (Example primary, secondary).
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for System
      Settings GetAuthenticationAndPolicyServers
    description: Complete reference of the GetAuthenticationAndPolicyServers
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-authentication-and-policy-servers
notes:
  - SDK Method used are
    system_settings.SystemSettings.get_authentication_and_policy_servers,
  - Paths used are
    get /dna/intent/api/v1/authentication-policy-servers,
"""

EXAMPLES = r"""
---
- name: Get all Authentication Policy Servers
  cisco.dnac.authentication_policy_servers_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    isIseEnabled: true
    state_: string
    role: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "ipAddress": "string",
          "sharedSecret": "string",
          "protocol": "string",
          "role": "string",
          "port": 0,
          "authenticationPort": 0,
          "accountingPort": 0,
          "retries": 0,
          "timeoutSeconds": 0,
          "isIseEnabled": true,
          "instanceUuid": "string",
          "state": "string",
          "ciscoIseDtos": [
            {
              "subscriberName": "string",
              "description": "string",
              "password": "string",
              "userName": "string",
              "fqdn": "string",
              "ipAddress": "string",
              "trustState": "string",
              "instanceUuid": "string",
              "sshkey": "string",
              "type": "string",
              "failureReason": "string",
              "role": "string",
              "externalCiscoIseIpAddrDtos": {
                "type": "string",
                "externalCiscoIseIpAddresses": [
                  {
                    "externalIpAddress": "string"
                  }
                ]
              }
            }
          ],
          "encryptionScheme": "string",
          "messageKey": "string",
          "encryptionKey": "string",
          "useDnacCertForPxgrid": true,
          "iseEnabled": true,
          "pxgridEnabled": true,
          "rbacUuid": "string",
          "multiDnacEnabled": true
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wired_network_devices_id_config_features_intended_layer2_feature
short_description: Resource module for Wired Network Devices Id Config Features Intended Layer2 Feature
description:
  - Manage operations create, update and delete of the resource Wired Network Devices Id Config Features Intended Layer2 Feature.
  - This API creates configurations for an intended feature on a wired device. Once all the updates to intended features are complete, they can be deployed to a
    device using the API /dna/intent/api/v1/networkDevices/{id}/configFeatures/intended/deploy. When the intended features are deployed, they are applied on top
    of the existing configurations on the device. Any existing configurations on the device which are not included in the intended features, are retained on the
    device.
  - This API deletes the configurations for an intended feature on a wired device. Once all the updates to intended features are complete, they can be deployed
    to a device using the API /dna/intent/api/v1/networkDevices/{id}/configFeatures/intended/deploy. When the intended features are deployed, they are applied
    on top of the existing configurations on the device. Any existing configurations on the device which are not included in the intended features, are
    retained on the device.
  - This API updates the configurations for an intended feature on a wired device. Updates to other intended features can be done over several iterations.
    Once all the updates to intended features are complete, they can be deployed to a device using the API
    /dna/intent/api/v1/networkDevices/{id}/configFeatures/intended/deploy. When the intended features are deployed, they are applied on top of the existing
    configurations on the device. Any existing configurations on the device which are not included in the intended features, are retained on the device.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  cdpGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's cdpGlobalConfig.
    type: dict
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        type: list
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality configured for CDP. Config type CDP_GLOBAL is for configuring the global settings for CDP.
            type: str
          holdTime:
            description: Specifies the amount of time a receiving device should hold the information sent by the device before discarding it. Corresponding CLI
              cdp holdtime <10-255>.
            type: int
          isAdvertiseV2Enabled:
            description: Configures CDP to send Version-2 advertisements. The default state is enabled. Corresponding CLI - cdp advertise-v2.
            type: bool
          isCdpEnabled:
            description: Enables or disables CDP on the device. Corresponding CLI - cdp run. Default true.
            type: bool
          isLogDuplexMismatchEnabled:
            description: Configures the reporting of duplex mismatches generated by CDP for all Ethernet interfaces on the device. Corresponding CLI - cdp log
              mismatch. Duplex. Default true.
            type: bool
          timer:
            description: Sets the transmission frequency of CDP updates in seconds. Corresponding CLI - cdp timer <5-254>.
            type: int
  cdpInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's cdpInterfaceConfig.
    type: dict
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        type: list
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type CDP_INTERFACE is for configuring CDP on an interface.
            type: str
          interfaceName:
            description: Interface name. The API /dna/intent/api/v1/interface/network-device/{deviceId} can be used to get the list of interfaces on a device.
              Example GigabitEthernet1/0/1.
            type: str
          isCdpEnabled:
            description: Enables or disables CDP on the interface. Corresponding CLI - cdp enable. Default true.
            type: bool
          isLogDuplexMismatchEnabled:
            description: Configures the reporting of duplex mismatches generated by CDP for all Ethernet interfaces on the device. Corresponding CLI - cdp
              log mismatch duplex. Default true.
            type: bool
  dhcpSnoopingGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's dhcpSnoopingGlobalConfig.
    type: dict
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        type: list
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type DHCP_SNOOPING_GLOBAL is for configuring the global settings for DHCP
              snooping.
            type: str
          databaseAgent:
            description: Wired Network Devices Id Config Features Intended Layer2 Feature's databaseAgent.
            type: dict
            suboptions:
              agentUrl:
                description: Example tftp //192.168.1.100/db_backup Specify the URL for the database agent or the binding file. Corresponding CLI - ip dhcp
                  snooping database .
                type: str
              configType:
                description: Type of network functionality under a feature. Config type DHCP_SNOOPING_DATABASE_AGENT is for configuring DHCP snooping database
                  agent settings on a device.
                type: str
              timeout:
                description: Specify the duration, in seconds, after which a configuration process will be automatically terminated. Corresponding CLI -
                  ip dhcp snooping database timeout <0-86400>.
                type: int
              writeDelay:
                description: WriteDelay.
                type: int
          dhcpSnoopingVlans:
            description: Enable DHCP snooping on VLANs. VLANs can be comma separated and/or a range like '2,4-5,7,10-20'. Corresponding CLI - ip dhcp snooping
              vlan .
            type: str
          isDhcpSnoopingEnabled:
            description: Enable DHCP snooping globally. Corresponding CLI - ip dhcp snooping.default false.
            type: bool
          isGleaningEnabled:
            description: Enable DHCP gleaning which allows components to register and glean only DHCP version 4 packets. Corresponding CLI - ip dhcp snooping
              glean.default false.
            type: bool
          proxyBridgeVlans:
            description: Enable bridge mode on VLANs. VLANs can be comma separated and/or a range like '2,4-5,7,10-20'. Corresponding CLI - ip dhcp snooping
              vlan proxy-bridge.
            type: str
  dhcpSnoopingInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's dhcpSnoopingInterfaceConfig.
    type: dict
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        type: list
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type DHCP_SNOOPING_INTERFACE is for configuring DHCP snooping on an interface.
            type: str
          interfaceName:
            description: Interface name. The API /intent/api/v1/interface/network-device/{deviceId} can be used to get the list of interfaces on a
              device.example GigabitEthernet1/0/1.
            type: str
          isTrustedInterface:
            description: Enable Trusted Interface. Corresponding CLI - ip dhcp snooping trust.
            type: bool
          messageRateLimit:
            description: Limit the number of DHCP packets a port can send or receive in a second. This is a protective measure to prevent a single device from
              overwhelming the DHCP server. Increase the rate limit on trunk ports carrying more than one VLAN. By default, rate limit is disabled. The
              recommended value is <= 100. Set the rate-limit as 0 to disable it. Corresponding CLI - ip dhcp snooping limit rate <1-2048>.
            type: int
  dot1xGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's dot1xGlobalConfig.
    type: dict
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        type: list
        elements: dict
        suboptions:
          authenticationConfigMode:
            description: ReadOnly attribute. Identity-Based Networking Services features are configured in the Cisco common classification policy language
              (C3PL) display mode. The legacy authentication manager mode is enabled by default. Use this command in EXEC mode to display the current
              configuration mode. Corresponding CLI - authentication display config-mode. LEGACY - Legacy configuration mode. NEW_STYLE - Identity-Based
              Networking Services (IBNS) configuration mode.
            type: str
          configType:
            description: Type of network functionality under a feature. Config type DOT1X_GLOBAL is for global 802.1x settings on a device.
            type: str
          isDot1xEnabled:
            description: Globally enable 802.1x authentication on Switch. Corresponding CLI - dot1x system-auth-control. Default false.
            type: bool
  dot1xInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's dot1xInterfaceConfig.
    type: dict
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        type: list
        elements: dict
        suboptions:
          authenticationOrder:
            description: Wired Network Devices Id Config Features Intended Layer2 Feature's authenticationOrder.
            type: dict
            suboptions:
              configType:
                description: ConfigType.
                type: str
              items:
                description: Array of Enums. DOT1X, MAB, WEBAUTH.
                type: list
                elements: str
          configType:
            description: Type of network functionality under a feature. Config type DOT1X_INTERFACE is for configuring 802.1x on an interface.
            type: str
          interfaceName:
            description: Interface name. The API /intent/api/v1/interface/network-device/{deviceId} can be used to get the list of interfaces on a
              device.example GigabitEthernet1/0/1.
            type: str
  feature:
    description: Feature path parameter. Name of the feature to delete.
    type: str
  id:
    description: Id path parameter. Network device ID of the wired device to configure.
    type: str
  igmpSnoopingGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's igmpSnoopingGlobalConfig.
    type: dict
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        type: list
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type IGMP_SNOOPING_GLOBAL is for configuring global IGMP snooping settings on a
              device.
            type: str
          igmpSnoopingVlanSettings:
            description: Wired Network Devices Id Config Features Intended Layer2 Feature's igmpSnoopingVlanSettings.
            type: dict
            suboptions:
              configType:
                description: ConfigType.
                type: str
              items:
                description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                type: list
                elements: dict
                suboptions:
                  configType:
                    description: Type of network functionality under a feature. Config type IGMP_SNOOPING_VLAN is for configuring IGMP snooping per VLAN.
                    type: str
                  igmpSnoopingVlanMrouters:
                    description: Wired Network Devices Id Config Features Intended Layer2 Feature's igmpSnoopingVlanMrouters.
                    type: dict
                    suboptions:
                      configType:
                        description: Type of IGMP Snooping Mrouter Settings.
                        type: str
                      items:
                        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                        type: list
                        elements: dict
                        suboptions:
                          configType:
                            description: Type of network functionality under a feature. Config type IGMP_SNOOPING_VLAN_MROUTER is for configuring IGMP snooping
                              mrouter per VLAN.
                            type: str
                          interfaceName:
                            description: Mrouter interface name. The API /dna/intent/api/v1/interface/network-dev... can be used to get the list of interfaces
                              on a device.example GigabitEthernet1/0/2.
                            type: str
                  isIgmpSnoopingEnabled:
                    description: Enable IGMP Snooping for a VLAN. Corresponding CLI - ip igmp snooping vlan <1-4094>.
                    type: bool
                  isImmediateLeaveEnabled:
                    description: Enable immediate leave processing for IGMPv2. Corresponding CLI - ip igmp snooping vlan <vlan-id> immediate-leave.default
                      false.
                    type: bool
                  isQuerierEnabled:
                    description: Enable IGMP querier for this VLAN. Corresponding CLI - ip igmp snooping vlan <vlan-id> querier.
                    type: bool
                  querierAddress:
                    description: IGMP querier source IP address. Corresponding CLI - ip igmp snooping vlan <vlan-id> querier address <ip-address>.
                    type: str
                  querierQueryInterval:
                    description: Set the IGMP querier query interval (in seconds). Corresponding CLI - ip igmp snooping vlan <vlan-id> querier query-interval
                      <1-18000>.
                    type: int
                  querierVersion:
                    description: The switch supports IGMP version 1, IGMP version 2, and IGMP version 3. These versions are interoperable on the switch.
                      For example, if IGMP snooping is enabled and the querier's version is IGMPv2, and the switch receives an IGMPv3 report from a host, then
                      the switch can forward the IGMPv3 report to the multicast router. Corresponding CLI - ip igmp snooping querier version <1-3>. IGMP
                      version 1 provides the basic query-response mechanism that allows the multicast device to determine which multicast groups are active and
                      other processes that enable hosts to join and leave a multicast group. IGMP version 2 extends IGMP functionality by providing such
                      features as the IGMP leave process to reduce leave latency, group-specific queries, and an explicit maximum query response time.
                      IGMPv2 also adds the capability for routers to elect the IGMP querier without depending on the multicast protocol to perform this task.
                      An IGMP version 3 switch supports Basic IGMPv3SnoopingSupport (BISS), which includes support for the snooping features on IGMPv1
                      and IGMPv2 switches and for IGMPv3 membership report messages. BISS constrains the flooding of multicast traffic when your network
                      includes IGMPv3 hosts. It constrains traffic to approximately the same set of ports as the IGMP snooping feature on IGMPv2 or IGMPv
                      hosts. An IGMPv3 switch can receive messages from and forward messages to a device running theSourceSpecific Multicast (SSM) feature.
                    type: str
                  vlanId:
                    description: VLAN ID.
                    type: int
          isIgmpSnoopingEnabled:
            description: Enable global IGMP Snooping. Corresponding CLI - ip igmp snooping.default true.
            type: bool
          isQuerierEnabled:
            description: Enable IGMP Snooping Querier. Corresponding CLI - ip igmp snooping querier.default false.
            type: bool
          querierAddress:
            description: Configure IGMP querier source IP address. Corresponding CLI - ip igmp snooping querier address <ip-address>.
            type: str
          querierQueryInterval:
            description: Set the IGMP querier query interval (in seconds). Corresponding CLI - ip igmp snooping querier query-interval <1-18000>.
            type: int
          querierVersion:
            description: The switch supports IGMP version 1, IGMP version 2, and IGMP version 3. These versions are interoperable on the switch. For example,
              if IGMP snooping is enabled and the querier's version is IGMPv2, and the switch receives an IGMPv3 report from a host, then the switch can
              forward the IGMPv3 report to the multicast router. Corresponding CLI - ip igmp snooping querier version <1-3>. IGMP version 1 provides the basic
              query-response mechanism that allows the multicast device to determine which multicast groups are active and other processes that enable hosts to
              join and leave a multicast group. IGMP version 2 extends IGMP functionality by providing such features as the IGMP leave process to reduce leave
              latency, group-specific queries, and an explicit maximum query response time. IGMPv2 also adds the capability for routers to elect the IGMP
              querier without depending on the multicast protocol to perform this task. An IGMP version 3 switch supports Basic IGMPv3SnoopingSupport (BISS),
              which includes support for the snooping features on IGMPv1 and IGMPv2 switches and for IGMPv3 membership report messages. BISS constrains the
              flooding of multicast traffic when your network includes IGMPv3 hosts. It constrains traffic to approximately the same set of ports as the IGMP
              snooping feature on IGMPv2 or IGMPv1 hosts. An IGMPv3 switch can receive messages from and forward messages to a device running theSourceSpecific
              Multicast (SSM) feature.
            type: str
  lldpGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's lldpGlobalConfig.
    type: dict
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        type: list
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality configured for LLDP. Config type LLDP_GLOBAL is for configuring the global settings for LLDP.
            type: str
          holdTime:
            description: Specifies the amount of time a receiving device should hold the information sent by the device before discarding it. Corresponding
              CLI - lldp holdtime $holdTime <0-32767>.
            type: int
          isLldpEnabled:
            description: Enables or disables LLDP on the device. Corresponding CLI - lldp run. Default true.
            type: bool
          reinitializationDelay:
            description: Specifies the delay time in seconds for LLDP to initialize on any interface. Corresponding CLI - lldp reinit <2-5>.
            type: int
          timer:
            description: Sets the transmission frequency of LLDP updates in seconds. Corresponding CLI - lldp timer <5-32767>.
            type: int
  lldpInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's lldpInterfaceConfig.
    type: dict
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        type: list
        elements: dict
        suboptions:
          adminStatus:
            description: Configure the interface to transmit and receive LLDP packets, or disable LLDP on the interface. TRANSMIT_ONLY - Configure the
              interface to transmit LLDP packets only. Corresponding CLI - lldp transmit. RECEIVE_ONLY - Configure the interface to receive LLDP packets
              only. Corresponding CLI - lldp receive. TRANSMIT_AND_RECEIVE - Configure the interface to both transmit and receive LLDP packets. Corresponding
              CLI - lldp receive; lldp transmit. DISABLED - Disable LLDP functionality on the device, preventing both transmission and reception of LLDP
              packets.
            type: str
          configType:
            description: Type of network functionality under a feature. Config type LLDP_INTERFACE is for configuring LLDP on an interface.
            type: str
          interfaceName:
            description: Interface name. The API /intent/api/v1/interface/network-device/{deviceId} can be used to get the list of interfaces on a
              device. Example GigabitEthernet1/0/1.
            type: str
  mabInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's mabInterfaceConfig.
    type: dict
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        type: list
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type MAB_INTERFACE is for configuring MAB on an
              interface.
            type: str
          interfaceName:
            description: Interface name. The API /intent/api/v1/interface/network-device/{deviceId} can be used to get the list of interfaces on a device.
            type: str
          isMabEnabled:
            description: Enable MAC-based authentication on a port. Corresponding CLI - mab. Default false.
            type: bool
  mldSnoopingGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's mldSnoopingGlobalConfig.
    type: dict
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        type: list
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type MLD_SNOOPING_GLOBAL is for configuring MLD snooping settings on a device.
            type: str
          isMldSnoopingEnabled:
            description: Enable global MLD Snooping. Corresponding CLI - ipv6 mld snooping.default false.
            type: bool
          isQuerierEnabled:
            description: Enable MLD Snooping Querier. Corresponding CLI - ipv6 mld snooping querier.default false.
            type: bool
          isSuppressListenerMessagesEnabled:
            description: When Listener Message Suppression is enabled, the switch forwards only a single MLD report per multicast router query. Corresponding
              CLI - ipv6 mld snooping listener-message-suppression.default true.
            type: bool
          mldSnoopingVlanSettings:
            description: Wired Network Devices Id Config Features Intended Layer2 Feature's mldSnoopingVlanSettings.
            type: dict
            suboptions:
              configType:
                description: Type of MLD Snooping VLAN Settings.
                type: str
              items:
                description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                type: list
                elements: dict
                suboptions:
                  configType:
                    description: Type of network functionality under a feature. Config type MLD_SNOOPING_VLAN is for configuring MLD snooping per VLAN.
                    type: str
                  isImmediateLeaveEnabled:
                    description: Enable immediate leave processing for MLDv1. Corresponding CLI - ipv6 mld snooping vlan <vlan-id> immediate-leave.default
                      false.
                    type: bool
                  isMldSnoopingEnabled:
                    description: Enable MLD Snooping for a VLAN. Corresponding CLI - ipv6 mld snooping vlan <1-4094>.
                    type: bool
                  isQuerierEnabled:
                    description: Enable MLD querier for this VLAN. Corresponding CLI - ipv6 mld snooping vlan <vlan-id> querier.
                    type: bool
                  mldSnoopingVlanMrouters:
                    description: Wired Network Devices Id Config Features Intended Layer2 Feature's mldSnoopingVlanMrouters.
                    type: dict
                    suboptions:
                      configType:
                        description: Type of MLD Snooping Mrouter Settings.
                        type: str
                      items:
                        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                        type: list
                        elements: dict
                        suboptions:
                          configType:
                            description: Type of network functionality under a feature. Config type MLD_SNOOPING_VLAN_MROUTER is for configuring MLD snooping
                              mrouter per VLAN.
                            type: str
                          interfaceName:
                            description: Mrouter interface name. The API /dna/intent/api/v1/interface/network-dev... can be used to get the list of interfaces
                              on a device.example GigabitEthernet1/0/2.
                            type: str
                  querierAddress:
                    description: MLD querier source IP address. Corresponding CLI - ipv6 mld snooping vlan <vlan-id> querier address <source-ipv6-address>.
                    type: str
                  querierQueryInterval:
                    description: Set the MLD querier query interval (in seconds). Corresponding CLI - ipv6 mld snooping vlan <vlan-id> querier query-interval
                      <1-18000>.
                    type: int
                  querierVersion:
                    description: Configure MLD version. Corresponding CLI - ipv6 mld snooping vlan <vlan-id> querier version <1-2> VERSION_1 - MLDv1 snooping
                      detects MLDv1 control packets and sets up traffic bridging based on IPv6 destination multicast addresses. MLDv1 supports three types of
                      messages - Listener Queries, Multicast Listener Reports, Multicast Listener Done. VERSION_2 - MLDv2 basic snooping (MBSS) uses MLDv2
                      control packets to set up traffic forwarding based on IPv6 destination multicast addresses. MLDv2 supports MLDv2 queries and reports, as
                      well as MLDv1 Report and Done messages.
                    type: str
                  vlanId:
                    description: VLAN ID.
                    type: int
          querierAddress:
            description: MLD querier source IP address. Corresponding CLI - ipv6 mld snooping querier address <source-ipv6-address>.
            type: str
          querierQueryInterval:
            description: Set the MLD querier query interval (in seconds). Corresponding CLI - ipv6 mld snooping querier query-interval <1-18000>.
            type: int
          querierVersion:
            description: Configure the MLD version. Corresponding CLI - ipv6 mld snooping querier version <1-2> VERSION_1 - MLDv1 snooping detects MLDv1
              control packets and sets up traffic bridging based on IPv6 destination multicast addresses. MLDv1 supports three types of messages -
              Listener Queries, Multicast Listener Reports, Multicast Listener Done. VERSION_2 - MLDv2 basic snooping (MBSS) uses MLDv2 control packets to set
              up traffic forwarding based on IPv6 destination multicast addresses. MLDv2 supports MLDv2 queries and reports, as well as MLDv1 Report and Done
              messages.
            type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Wired CreateConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice
  description: Complete reference of the CreateConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice API.
  link: https://developer.cisco.com/docs/dna-center/#!create-configurations-for-an-intended-layer-2-feature-on-a-wired-device
- name: Cisco DNA Center documentation for Wired DeleteConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice
  description: Complete reference of the DeleteConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice API.
  link: https://developer.cisco.com/docs/dna-center/#!delete-configurations-for-an-intended-layer-2-feature-on-a-wired-device
- name: Cisco DNA Center documentation for Wired UpdateConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice
  description: Complete reference of the UpdateConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice API.
  link: https://developer.cisco.com/docs/dna-center/#!update-configurations-for-an-intended-layer-2-feature-on-a-wired-device
notes:
- SDK Method used are wired.Wired.create_configurations_for_an_intended_layer2_feature_on_a_wired_device,
  wired.Wired.delete_configurations_for_an_intended_layer2_feature_on_a_wired_device,
  wired.Wired.update_configurations_for_an_intended_layer2_feature_on_a_wired_device,
- Paths used are post /dna/intent/api/v1/wired/networkDevices/{id}/configFeatures/intended/layer2/{feature},
  delete /dna/intent/api/v1/wired/networkDevices/{id}/configFeatures/intended/layer2/{feature},
  put /dna/intent/api/v1/wired/networkDevices/{id}/configFeatures/intended/layer2/{feature},
"""

EXAMPLES = r"""
---
- name: Delete by id
  cisco.dnac.wired_network_devices_id_config_features_intended_layer2_feature:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    feature: string
    id: string
- name: Update by id
  cisco.dnac.wired_network_devices_id_config_features_intended_layer2_feature:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    cdpGlobalConfig:
      items:
        - - configType: string
            holdTime: 0
            isAdvertiseV2Enabled: true
            isCdpEnabled: true
            isLogDuplexMismatchEnabled: true
            timer: 0
    cdpInterfaceConfig:
      items:
        - - configType: string
            interfaceName: string
            isCdpEnabled: true
            isLogDuplexMismatchEnabled: true
    dhcpSnoopingGlobalConfig:
      items:
        - - configType: string
            databaseAgent:
              agentUrl: string
              configType: string
              timeout: 0
              writeDelay: 0
            dhcpSnoopingVlans: string
            isDhcpSnoopingEnabled: true
            isGleaningEnabled: true
            proxyBridgeVlans: string
    dhcpSnoopingInterfaceConfig:
      items:
        - - configType: string
            interfaceName: string
            isTrustedInterface: true
            messageRateLimit: 0
    dot1xGlobalConfig:
      items:
        - - authenticationConfigMode: string
            configType: string
            isDot1xEnabled: true
    dot1xInterfaceConfig:
      items:
        - - authenticationOrder:
              configType: string
              items:
                - string
            configType: string
            interfaceName: string
    feature: string
    id: string
    igmpSnoopingGlobalConfig:
      items:
        - - configType: string
            igmpSnoopingVlanSettings:
              configType: string
              items:
                - configType: string
                  igmpSnoopingVlanMrouters:
                    configType: string
                    items:
                      - configType: string
                        interfaceName: string
                  isIgmpSnoopingEnabled: true
                  isImmediateLeaveEnabled: true
                  isQuerierEnabled: true
                  querierAddress: string
                  querierQueryInterval: 0
                  querierVersion: string
                  vlanId: 0
            isIgmpSnoopingEnabled: true
            isQuerierEnabled: true
            querierAddress: string
            querierQueryInterval: 0
            querierVersion: string
    lldpGlobalConfig:
      items:
        - - configType: string
            holdTime: 0
            isLldpEnabled: true
            reinitializationDelay: 0
            timer: 0
    lldpInterfaceConfig:
      items:
        - - adminStatus: string
            configType: string
            interfaceName: string
    mabInterfaceConfig:
      items:
        - - configType: string
            interfaceName: string
            isMabEnabled: true
    mldSnoopingGlobalConfig:
      items:
        - - configType: string
            isMldSnoopingEnabled: true
            isQuerierEnabled: true
            isSuppressListenerMessagesEnabled: true
            mldSnoopingVlanSettings:
              configType: string
              items:
                - configType: string
                  isImmediateLeaveEnabled: true
                  isMldSnoopingEnabled: true
                  isQuerierEnabled: true
                  mldSnoopingVlanMrouters:
                    configType: string
                    items:
                      - configType: string
                        interfaceName: string
                  querierAddress: string
                  querierQueryInterval: 0
                  querierVersion: string
                  vlanId: 0
            querierAddress: string
            querierQueryInterval: 0
            querierVersion: string
    portChannelConfig:
      items:
        - - configType: string
            isAutoEnabled: true
            lacpSystemPriority: 0
            loadBalancingMethod: string
            portchannels:
              configType: string
              items:
                - AnyOf:
                    EtherchannelConfig:
                      configType: string
                      memberPorts:
                        configType: string
                        items:
                          - configType: string
                            interfaceName: string
                            mode: string
                      minLinks: 0
                      name: string
                    LacpPortchannelConfig:
                      configType: string
                      memberPorts:
                        configType: string
                        items:
                          - configType: string
                            interfaceName: string
                            mode: string
                            portPriority: 0
                            rate: 0
                      minLinks: 0
                      name: string
                    PagpPortchannelConfig:
                      configType: string
                      memberPorts:
                        configType: string
                        items:
                          - configType: string
                            interfaceName: string
                            learnMethod: string
                            mode: string
                            portPriority: 0
                      minLinks: 0
                      name: string
    stpGlobalConfig:
      items:
        - - configType: string
            isBackboneFastEnabled: true
            isBpduFilterEnabled: true
            isBpduGuardEnabled: true
            isEtherChannelGuardEnabled: true
            isExtendedSystemIdEnabled: true
            isLoggingEnabled: true
            isLoopGuardEnabled: true
            isUplinkFastEnabled: true
            portFastMode: string
            stpInstances:
              configType: string
              items:
                - configType: string
                  priority: 0
                  timers:
                    configType: string
                    forwardDelay: 0
                    helloInterval: 0
                    isStpEnabled: true
                    maxAge: 0
                  vlanId: 0
            stpMode: string
            transmitHoldCount: 0
            uplinkFastMaxUpdateRate: 0
    stpInterfaceConfig:
      items:
        - bpduFilter: string
          bpduGuard: string
          configType: string
          guardMode: string
          interfaceName: string
          pathCost: 0
          portFastMode: string
          portVlanCostSettings:
            configType: string
            items:
              - configType: string
                cost: 0
                vlans: string
          portVlanPrioritySettings:
            configType: string
            items:
              - configType: string
                priority: 0
                vlans: string
          priority: 0
    switchportInterfaceConfig:
      items:
        - - accessVlan: 0
            adminStatus: string
            configType: string
            description: string
            interfaceName: string
            mode: string
            nativeVlan: 0
            trunkAllowedVlans: string
            voiceVlan: 0
    trunkInterfaceConfig:
      items:
        - - configType: string
            interfaceName: string
            isDtpNegotiationEnabled: true
            isProtected: true
            pruneEligibleVlans: string
    vlanConfig:
      items:
        - - configType: string
            isVlanEnabled: true
            name: string
            vlanId: 0
    vtpGlobalConfig:
      items:
        - - configType: string
            configurationFileName: string
            domainName: string
            isPruningEnabled: true
            mode: string
            sourceInterface: string
            version: string
    vtpInterfaceConfig:
      items:
        - - configType: string
            interfaceName: string
            isVtpEnabled: true
- name: Create
  cisco.dnac.wired_network_devices_id_config_features_intended_layer2_feature:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    cdpGlobalConfig:
      items:
        - - configType: string
            holdTime: 0
            isAdvertiseV2Enabled: true
            isCdpEnabled: true
            isLogDuplexMismatchEnabled: true
            timer: 0
    cdpInterfaceConfig:
      items:
        - - configType: string
            interfaceName: string
            isCdpEnabled: true
            isLogDuplexMismatchEnabled: true
    dhcpSnoopingGlobalConfig:
      items:
        - - configType: string
            databaseAgent:
              agentUrl: string
              configType: string
              timeout: 0
              writeDelay: 0
            dhcpSnoopingVlans: string
            isDhcpSnoopingEnabled: true
            isGleaningEnabled: true
            proxyBridgeVlans: string
    dhcpSnoopingInterfaceConfig:
      items:
        - - configType: string
            interfaceName: string
            isTrustedInterface: true
            messageRateLimit: 0
    dot1xGlobalConfig:
      items:
        - - authenticationConfigMode: string
            configType: string
            isDot1xEnabled: true
    dot1xInterfaceConfig:
      items:
        - - authenticationOrder:
              configType: string
              items:
                - string
            configType: string
            interfaceName: string
    feature: string
    id: string
    igmpSnoopingGlobalConfig:
      items:
        - - configType: string
            igmpSnoopingVlanSettings:
              configType: string
              items:
                - configType: string
                  igmpSnoopingVlanMrouters:
                    configType: string
                    items:
                      - configType: string
                        interfaceName: string
                  isIgmpSnoopingEnabled: true
                  isImmediateLeaveEnabled: true
                  isQuerierEnabled: true
                  querierAddress: string
                  querierQueryInterval: 0
                  querierVersion: string
                  vlanId: 0
            isIgmpSnoopingEnabled: true
            isQuerierEnabled: true
            querierAddress: string
            querierQueryInterval: 0
            querierVersion: string
    lldpGlobalConfig:
      items:
        - - configType: string
            holdTime: 0
            isLldpEnabled: true
            reinitializationDelay: 0
            timer: 0
    lldpInterfaceConfig:
      items:
        - - adminStatus: string
            configType: string
            interfaceName: string
    mabInterfaceConfig:
      items:
        - - configType: string
            interfaceName: string
            isMabEnabled: true
    mldSnoopingGlobalConfig:
      items:
        - - configType: string
            isMldSnoopingEnabled: true
            isQuerierEnabled: true
            isSuppressListenerMessagesEnabled: true
            mldSnoopingVlanSettings:
              configType: string
              items:
                - configType: string
                  isImmediateLeaveEnabled: true
                  isMldSnoopingEnabled: true
                  isQuerierEnabled: true
                  mldSnoopingVlanMrouters:
                    configType: string
                    items:
                      - configType: string
                        interfaceName: string
                  querierAddress: string
                  querierQueryInterval: 0
                  querierVersion: string
                  vlanId: 0
            querierAddress: string
            querierQueryInterval: 0
            querierVersion: string
    portChannelConfig:
      items:
        - - configType: string
            isAutoEnabled: true
            lacpSystemPriority: 0
            loadBalancingMethod: string
            portchannels:
              configType: string
              items:
                - AnyOf:
                    EtherchannelConfig:
                      configType: string
                      memberPorts:
                        configType: string
                        items:
                          - configType: string
                            interfaceName: string
                            mode: string
                      minLinks: 0
                      name: string
                    LacpPortchannelConfig:
                      configType: string
                      memberPorts:
                        configType: string
                        items:
                          - configType: string
                            interfaceName: string
                            mode: string
                            portPriority: 0
                            rate: 0
                      minLinks: 0
                      name: string
                    PagpPortchannelConfig:
                      configType: string
                      memberPorts:
                        configType: string
                        items:
                          - configType: string
                            interfaceName: string
                            learnMethod: string
                            mode: string
                            portPriority: 0
                      minLinks: 0
                      name: string
    stpGlobalConfig:
      items:
        - - configType: string
            isBackboneFastEnabled: true
            isBpduFilterEnabled: true
            isBpduGuardEnabled: true
            isEtherChannelGuardEnabled: true
            isExtendedSystemIdEnabled: true
            isLoggingEnabled: true
            isLoopGuardEnabled: true
            isUplinkFastEnabled: true
            portFastMode: string
            stpInstances:
              configType: string
              items:
                - configType: string
                  priority: 0
                  timers:
                    configType: string
                    forwardDelay: 0
                    helloInterval: 0
                    isStpEnabled: true
                    maxAge: 0
                  vlanId: 0
            stpMode: string
            transmitHoldCount: 0
            uplinkFastMaxUpdateRate: 0
    stpInterfaceConfig:
      items:
        - bpduFilter: string
          bpduGuard: string
          configType: string
          guardMode: string
          interfaceName: string
          pathCost: 0
          portFastMode: string
          portVlanCostSettings:
            configType: string
            items:
              - configType: string
                cost: 0
                vlans: string
          portVlanPrioritySettings:
            configType: string
            items:
              - configType: string
                priority: 0
                vlans: string
          priority: 0
    switchportInterfaceConfig:
      items:
        - - accessVlan: 0
            adminStatus: string
            configType: string
            description: string
            interfaceName: string
            mode: string
            nativeVlan: 0
            trunkAllowedVlans: string
            voiceVlan: 0
    trunkInterfaceConfig:
      items:
        - - configType: string
            interfaceName: string
            isDtpNegotiationEnabled: true
            isProtected: true
            pruneEligibleVlans: string
    vlanConfig:
      items:
        - - configType: string
            isVlanEnabled: true
            name: string
            vlanId: 0
    vtpGlobalConfig:
      items:
        - - configType: string
            configurationFileName: string
            domainName: string
            isPruningEnabled: true
            mode: string
            sourceInterface: string
            version: string
    vtpInterfaceConfig:
      items:
        - - configType: string
            interfaceName: string
            isVtpEnabled: true
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: device_reboot_apreboot
short_description: Resource module for Device Reboot
  Apreboot
description:
  - Manage operation create of the resource Device Reboot
    Apreboot.
  - Users can reboot multiple access points up-to 200
    at a time using this API.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  apMacAddresses:
    description: The ethernet MAC address of the access
      point.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      RebootAccessPoints
    description: Complete reference of the RebootAccessPoints
      API.
    link: https://developer.cisco.com/docs/dna-center/#!reboot-access-points
notes:
  - SDK Method used are
    wireless.Wireless.reboot_access_points,
  - Paths used are
    post /dna/intent/api/v1/device-reboot/apreboot,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.device_reboot_apreboot:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    apMacAddresses:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_profiles_id_site_tags_site_tag_id_info
short_description: Information module for Wireless Profiles
  Id Site Tags Site Tag Id
description:
  - Get Wireless Profiles Id Site Tags Site Tag Id by
    id. - > This endpoint retrieves the details of a
    specific `Site Tag` associated with a given `Wireless
    Profile`. This API requires the `id` of the `Wireless
    Profile` and the `siteTagId` of the `Site Tag`.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Wireless Profile Id.
    type: str
  siteTagId:
    description:
      - SiteTagId path parameter. Site Tag Id.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      RetrieveASpecificSiteTagForAWirelessProfile
    description: Complete reference of the RetrieveASpecificSiteTagForAWirelessProfile
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-a-specific-site-tag-for-a-wireless-profile
notes:
  - SDK Method used are
    wireless.Wireless.retrieve_a_specific_site_tag_for_a_wireless_profile,
  - Paths used are
    get /dna/intent/api/v1/wirelessProfiles/{id}/siteTags/{siteTagId},
"""

EXAMPLES = r"""
---
- name: Get Wireless Profiles Id Site Tags Site Tag
    Id by id
  cisco.dnac.wireless_profiles_id_site_tags_site_tag_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    siteTagId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "siteIds": [
          "string"
        ],
        "siteTagName": "string",
        "flexProfileName": "string",
        "apProfileName": "string",
        "siteTagId": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_id_info
short_description: Information module for Network Devices
  Id
description:
  - Get Network Devices Id by id. - > API to fetch the
    details of network device using the `id`. Use the
    `/dna/intent/api/v1/networkDevices/query` API for
    advanced filtering. The API supports views to fetch
    only the required fields. Refer features for more
    details.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Unique identifier for the
        network device.
    type: str
  views:
    description:
      - >
        Views query parameter. The specific views being
        requested. This is an optional parameter which
        can be passed to get one or more of the network
        device data. If this is not provided, then it
        will default to BASIC views. If multiple views
        are provided, the response will contain the
        union of the views. Available values BASIC,
        RESYNC, USER_DEFINED_FIELDS.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      GetDetailsOfASingleNetworkDevice
    description: Complete reference of the GetDetailsOfASingleNetworkDevice
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-details-of-a-single-network-device
notes:
  - SDK Method used are
    devices.Devices.get_details_of_a_single_network_device,
  - Paths used are
    get /dna/intent/api/v1/networkDevices/{id},
"""

EXAMPLES = r"""
---
- name: Get Network Devices Id by id
  cisco.dnac.network_devices_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    views: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "managementAddress": "string",
        "dnsResolvedManagementIpAddress": "string",
        "hostname": "string",
        "macAddress": "string",
        "serialNumbers": [
          "string"
        ],
        "type": "string",
        "family": "string",
        "series": "string",
        "status": "string",
        "platformIds": [
          "string"
        ],
        "softwareType": "string",
        "softwareVersion": "string",
        "vendor": "string",
        "stackDevice": true,
        "bootTime": 0,
        "role": "string",
        "roleSource": "string",
        "apEthernetMacAddress": "string",
        "apManagerInterfaceIpAddress": "string",
        "apWlcIpAddress": "string",
        "deviceSupportLevel": "string",
        "snmpLocation": "string",
        "snmpContact": "string",
        "reachabilityStatus": "string",
        "reachabilityFailureReason": "string",
        "managementState": "string",
        "lastSuccessfulResyncReasons": [
          "string"
        ],
        "resyncStartTime": 0,
        "resyncEndTime": 0,
        "resyncReasons": [
          "string"
        ],
        "resyncRequestedByApps": [
          "string"
        ],
        "pendingResyncRequestCount": 0,
        "pendingResyncRequestReasons": [
          "string"
        ],
        "resyncIntervalSource": "string",
        "resyncIntervalMinutes": 0,
        "errorCode": "string",
        "errorDescription": "string",
        "userDefinedFields": {}
      },
      "version": "string"
    }
"""
